/* --------------------------------------------------------------------------
    This is a sample GetDP problem definition file                           

    This file includes the file 'Magnetostatics.pro'

    (C) 1998 P. Dular, C. Geuzaine
   -------------------------------------------------------------------------- */

/* 
   To solve the problem
   with vector potential, type 'getdp square -pre MagSta_a -cal -pos a'
*/

//
// Entities
//

Group {
	/* The numbers correspond to physical regions defined in 'square.geo' (the input 
	   to the GMSH meshing tool) */
	
	Mag		  = Region[ 97 ];				// Magnet square
      Mag1		  = Region[ 98 ];				// Magnet square
      Mag2		  = Region[ 99 ];				// Magnet square
      Mag3		  = Region[ 100 ];			// Magnet square
	Air           = Region[ 101 ];		      // Surrounding Air
	
	Bound  	  = Region[ 1000 ] ;			// System boundaries
	
	Omega     = Region[ { Air, Mag, Mag1, Mag2, Mag3 } ];
	Magnet    = Region[ { Mag } ] ;
      Magnet1    = Region[ { Mag1 } ] ;
      Magnet2    = Region[ { Mag2 } ] ;
      Magnet3    = Region[ { Mag3 } ] ;

}


//
// Constants
//

Function {
	mu0     		= 4.e-7 * Pi ;		// Permeability
	mu[ Magnet ] 	= 1.05 * mu0;
	mu[ Magnet1 ] 	= 1.05 * mu0;
      mu[ Magnet2 ] 	= 1.05 * mu0;
	mu[ Magnet3 ] 	= 1.05 * mu0;
	mu[ Air ]		= mu0;
	
	nu[ Magnet ]    = 1.0 / (1.05 * mu0) ;
      nu[ Magnet1 ]    = 1.0 / (1.05 * mu0) ;
      nu[ Magnet2 ]    = 1.0 / (1.05 * mu0) ;
      nu[ Magnet3 ]    = 1.0 / (1.05 * mu0) ;
	nu[ Air ]		= 1.0 / mu0;
	
	hc[ Magnet ]  	= Vector[ 903000., 0., 0. ];
      hc[ Magnet1 ]  	= Vector[ -903000., 0., 0. ];
      hc[ Magnet2 ]  	= Vector[ 903000., 0., 0. ];
      hc[ Magnet3 ]  	= Vector[ -903000., 0., 0. ];
}


//
// Boundary Conditions
//

Constraint {
	{ Name a ;
		Case {
			{ Region Bound ; Value 0. ; }
		}
	}
}


//
// Governing Equations
//

Include "magnetForce2D_4magnets_ms.pro"


//
// Post Processing
//

eps = 1.e-8 ;

PostOperation {
	{ Name a ; NameOfPostProcessing MagSta_a;
		Operation {
			 // Print[ b, OnElementsOf Omega, File "b_d1.pos" ] ;
			 Print[ h, OnElementsOf Omega, File "h_d1.pos" ] ;
                   Print[ h, OnPlane { {0.001, -0.009,0} { 0.01,-0.009,0} {0.001, 0.022,0}} {30,86}, File "MF_4magnets.pos" ];
		}
	}
}