/* --------------------------------------------------------------------------
    This is a sample GetDP problem definition file                           
    for simple two-dimensionnal Magnetostatic problems                              

    (C) 1998 P. Dular, C. Geuzaine
   -------------------------------------------------------------------------- */


/* Input

  Groups :
  --------
    Omega          Whole magnetic domain
    Magnet         Permanent magnet regions 
		 
  Functions :	 
  -----------	 
    mu[]           Magnetic permeability
    nu[]           Magnetic reluctivity
    hc[]           Coercitive magnetic field
    
  Constraint :	 
  ----------	 
    a              Fixed magnetic vector potential (2D)

*/



Jacobian {
	{ Name JVol ;
		Case { 
			{ Region All; Jacobian Vol; }
		}
	}
}


Integration {
	{ Name I1 ;
		Case { 
			{ Type Gauss ;
				Case { 
					{ GeoElement Triangle    ; NumberOfPoints  4 ; }
					{ GeoElement Quadrangle  ; NumberOfPoints  4 ; }
				}
			}
		}
	}
}


/* -------------------------------------------------------------------------- 
   MagSta_a : Magnetic vector potential a formulation (2D) 
   -------------------------------------------------------------------------- */

FunctionSpace {
	{ Name Hcurl_a ; Type Form1P ;
		BasisFunction {
			{ Name se ; NameOfCoef ae ; Function BF_PerpendicularEdge ;
			  Support Omega ; Entity NodesOf[ All ] ; }
		}
		Constraint {
			{ NameOfCoef ae ; EntityType NodesOf ; NameOfConstraint a ; }
		}
	}
}


Formulation {
	{ Name MagSta_a ; Type FemEquation ;
		Quantity {
			{ Name a  ; Type Local ; NameOfSpace Hcurl_a ; }
		}
		Equation {
			Galerkin { [ nu[] * Dof{d a} , {d a} ] ; 
			           In Omega ; Jacobian JVol ; Integration I1 ; }
			Galerkin { [ hc[] , {d a} ] ; 
			           In Magnet ; Jacobian JVol ; Integration I1 ; }
			Galerkin { [ hc[] , {d a} ] ; 
			           In Magnet1 ; Jacobian JVol ; Integration I1 ; }
                  Galerkin { [ hc[] , {d a} ] ; 
			           In Magnet2 ; Jacobian JVol ; Integration I1 ; }
                  Galerkin { [ hc[] , {d a} ] ; 
			           In Magnet3 ; Jacobian JVol ; Integration I1 ; }

		}
	}
}


Resolution {
	{ Name MagSta_a ;
		System {
			{ Name A ; NameOfFormulation MagSta_a ; }
		}
		Operation { 
			Generate[A] ; Solve[A] ; SaveSolution[A] ;
		}
	}
}


PostProcessing {
	{ Name MagSta_a ; NameOfFormulation MagSta_a ;
		Quantity {
			{ Name a ; Value { Local { [ CompZ[{a}] ]   ; In Omega ; Jacobian JVol ; } } }
			{ Name b ; Value { Local { [ {d a} ]        ; In Omega ; Jacobian JVol ; } } }
			{ Name a ; Value { Local { [ {a} ]          ; In Omega ; Jacobian JVol ; } } }
			{ Name h ; Value { Local { [ nu[] * {d a} ] ; In Omega ; Jacobian JVol ; } 
			                   Local { [ hc[] ]         ; In Magnet ; Jacobian JVol ; }
			                   Local { [ hc[] ]         ; In Magnet1 ; Jacobian JVol ; }
                                     Local { [ hc[] ]         ; In Magnet2 ; Jacobian JVol ; }
			                   Local { [ hc[] ]         ; In Magnet3 ; Jacobian JVol ; } } }
		}
	}
}